Introduction
============

This addon provide twitter's bootstrap as browser resource.

Version: 3.0.0-wip

Resources::

  ++resource++collective.js.bootstrap/
  ++resource++collective.js.bootstrap/js/bootstrap.js
  ++resource++collective.js.bootstrap/js/bootstrap.min.js
  ++resource++collective.js.bootstrap/css/bootstrap.css
  ++resource++collective.js.bootstrap/css/bootstrap.min.css
  ++resource++collective.js.bootstrap/css/bootstrap-responsive.css
  ++resource++collective.js.bootstrap/css/bootstrap-responsive.min.css
  ++resource++collective.js.bootstrap/fonts/glyphiconshalflings-regular.eot
  ++resource++collective.js.bootstrap/fonts/glyphiconshalflings-regular.otf
  ++resource++collective.js.bootstrap/fonts/glyphiconshalflings-regular.svg
  ++resource++collective.js.bootstrap/fonts/glyphiconshalflings-regular.ttf
  ++resource++collective.js.bootstrap/fonts/glyphiconshalflings-regular.woff

About Twitter Bootstrap
=======================

Sleek, intuitive, and powerful front-end framework for faster and 
easier web development.

By nerds, for nerds: Built Twitter by @mdo and @fat, Bootstrap utilizes LESS CSS,
is compiled via Node, and is managed through GitHub to help nerds do awesome
stuff on the web.
Made for everyone.

Made for everyone: Bootstrap was made to not only look and behave great in the latest desktop
browsers (as well as IE7!), but in tablet and smartphone browsers via
responsive CSS as well.

Packed with features: A 12-column responsive grid, dozens of components,
JavaScript plugins, typography, form controls, and even a web-based Customizer
to make Bootstrap your own.

How to install
==============

This addon just need to be present in the zope instance. No profile to apply.

Credits
=======

Companies
---------

* `Planet Makina Corpus <http://www.makina-corpus.org>`_
* `Contact Makina Corpus <mailto:python@makina-corpus.org>`_

People
------

- JeanMichel FRANCOIS aka toutpt <toutpt@gmail.com>

.. _documentation: http://plone.org/documentation/kb/installing-add-ons-quick-how-to
